##  How to implement Sustainable IT Transformation with SAP LeanIX
Enterprise architecture supported with SAP LeanIX can play an important role in supporting ESG initiatives.
SAP LeanIX provides an out-of-the-box ESG capability map to help you get started. It is a great starting guide on what you can do and what are the different areas you can focus on for your ESG initiatives. It helps you identify sustainability risks and opportunities in an organization's landscape, enabling you to develop strategies for ESG initiatives. ESG capability map report is supported by a dedicated ESG capability fact sheet type.
Admins of workspaces can add the ESG capability map, developed in collaboration with PwC, as a landscape report to workspaces from the Optional Features & Early Access section in the Administration menu.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fae857a44101486b0976e0d242f28_LowRes.png)
To help manage data and measure progress, SAP LeanIX focuses on five principal metrics -
  * Emissions- to measure the carbon footprint
  * Energy consumption - to assess the portion of renewable energy consumed
  * Electronic waste - to capture lifecycle and recycling data of IT components
  * Digital ethics - to capture digital ethics information
  * Provider evaluation - to include the sustainability score of the provider


These five metrics are incorporated as custom attributes of various fact sheets such as application, IT component, and provider fact sheets. Linking these custom attributes with the new ESG capability fact sheet ties everything together to give you the ability to carry out and manage the ESG transformation.
